#ifndef VERSION_H
#define VERSION_H

extern const char * version;

/* disabled for reproducible build */
//extern const char * compile_date;

#endif 
